@@ -16,7 +16,7 @@
  *  along with this library; if not, write to the Free Software
  *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *
- *  $Id: harglists.c,v 1.37.2.1 2005/03/22 01:31:46 renaud Exp $
+ *  $Id: harglists.c,v 1.37.2.2 2008/03/12 08:09:06 renaud Exp $
  *
  * Author: Jordan Hrycaj <jordan@mjh.teddy-net.com>
  *
@@ -85,15 +85,6 @@
 #define XMALLOC(x)  emalloc(x)
 #define XFREE(x)    efree(&(x))
 
-#define NEED_XREALLOC /* locally installed, no mem zero needed */
-#define XREALLOC(x,n) xrealloc(x,n)
-
-#ifdef DMALLOC
-#undef NEED_XREALLOC
-#undef XREALLOC
-#define XREALLOC(x,n) realloc(x,n)
-#endif
-
 
 /* local on-the-stack memory allocation */
 #ifdef HAVE_ALLOCA
@@ -150,7 +141,9 @@ struct _csts_desc {
 
 
 
+#ifdef  HARG_CREATE_DEBUG
 static void debug (const char *, long, long);
+#endif
 
 /* ------------------------------------------------------------------------- *
  *                       private variable                                    *
@@ -196,24 +189,6 @@ IFDEBUG (static int dbglevel = HARG_DEBUG);
 /* compare ignoring ptr key bits */
 #define verify_yekrtp_type(s,t)  (get_yekrtp_type ((s)^(t)) == 0)
 
-#ifdef NEED_XREALLOC
-static void *
-xrealloc
-  (void       *p,
-   unsigned size)
-{
-  void *q = realloc (p, size) ;
-  if (q == 0) {
-    /* on out of memory, let XMALLOC do the aborting job */
-    q = XMALLOC (size) ;
-    memcpy (q, p, size) ;
-    XFREE (p) ;
-    return q;
-  }
-  return q;
-}
-#endif /* NEED_XREALLOC */
-
 #ifdef HARG_LIST_TRACKER
 static void
 harg_tracker_add
@@ -273,7 +248,7 @@ say_closing
 #define say_closing(x,y)
 #endif /* HARG_CREATE_DEBUG */
 
-#ifdef HARG_DEBUG
+#ifdef  HARG_CREATE_DEBUG
 static void
 message
   (const char *s,
@@ -299,7 +274,7 @@ debug
 {
   message ("DEBUG: ", s, u, v, ".");
 }
-#endif /* HARG_DEBUG */
+#endif
 
 static harg*
 create_harg
@@ -490,7 +465,7 @@ do_printf
   if (R != 0) {
     char *s = query_key_hlst ((void**)R) ;
     if (ptype)
-      fprintf (stderr, "<0x%04X/%d> = ", (void*)s,(int)(s));
+      fprintf (stderr, "<0x%04X/%d> = ", (unsigned int)s,(int)(s));
     else
       fprintf (stderr, "<%s> = ", s);
   } else {
@@ -674,8 +649,8 @@ harg_addt
 
   /* sanity check */
   if (a == 0 || key == 0 ||
-      size == 0 && ((value == 0) && is_blob_type (type) ||
-		    verify_simple_type (type, HARG_BLOB))) {
+      (size == 0 && (((value == 0) && is_blob_type (type)) ||
+		    verify_simple_type (type, HARG_BLOB)))) {
     errno = EINVAL; 
     return 0;
   }
@@ -738,8 +713,8 @@ harg_set_valuet
 
   /* sanity check */
   if (a == 0 || key == 0 ||
-      size == 0 && (value == 0 && is_blob_type (type) ||
-		    verify_simple_type (type, HARG_BLOB))) {
+      (size == 0 && ((value == 0 && is_blob_type (type)) ||
+		    verify_simple_type (type, HARG_BLOB)))) {
     errno = EINVAL; 
     return -1;
   }
@@ -828,8 +803,8 @@ harg_renamet
     return 0 ; /* nothing to do */
 
   /* check target type groups */
-  if (is_blob_type   (ntype) &&   is_blob_type (r->type) ||
-      is_scalar_type (ntype) && is_scalar_type (r->type) ||
+  if ((is_blob_type   (ntype) &&   is_blob_type (r->type)) ||
+      (is_scalar_type (ntype) && is_scalar_type (r->type)) ||
       is_specific_type (ntype) == 0) {
     if (same_keys == 0) {
       /* make new index */
