@@ -2224,8 +2224,6 @@ int internal_send(int soc, char * data, int msg_type )
  int len;
  int e;
  int ack;
- fd_set rd;
- struct timeval tv;
  
  if ( data == NULL )
 	data = "";
@@ -2259,8 +2257,6 @@ int internal_recv(int soc, char ** data, int * data_sz, int * msg_type )
  int e;
  char * buf = *data;
  int    sz  = *data_sz;
- fd_set rd;
- struct timeval tv;
  int type;
  int ack;
  
