@@ -902,7 +902,7 @@ int kb_get_port_state_proto(kb, prefs, portnum, proto)
  	return(1);
 	}
 	
- if(!port_in_ports(portnum, range, 0, num)){
+ if(!port_in_ports(portnum, range, 0, num - 1)){
        return unscanned_ports_as_closed(prefs);
        }
  
@@ -1023,10 +1023,7 @@ proto_post_wrapped(desc, port, proto, action, what)
  char * cve;
  char * bid;
  char * xref;
- int do_send = 1;
  int i;
- char ack;
- int n = 0, e, l;
   
     
  if( action == NULL )action = plug_get_description(desc);
@@ -1414,7 +1411,7 @@ void * plug_get_fresh_key(args, name, type)
 
  e = internal_send(soc, name, INTERNAL_COMM_MSG_TYPE_KB|INTERNAL_COMM_KB_GET);
  if(e < 0){
-        fprintf(stderr, "[%d] plug_get_fresh_key:internal_send(%d): %s\n",getpid(), soc,name, strerror(errno));
+        fprintf(stderr, "[%d] plug_get_fresh_key:internal_send(%d): %s\n",getpid(), soc,strerror(errno));
 	goto err;
 	}
 
@@ -1528,7 +1525,6 @@ scanner_add_port(args, port, proto)
  const char * hn = plug_get_hostname(args);
  int len;
  int soc;
- struct arglist * globs;
  int do_send = 1;
  static int confirm = -1;
  
@@ -1747,7 +1743,7 @@ plug_get_key(args, name, type)
       {
       int e;
       int status;
-      struct arglist * globals, * preferences = NULL;
+      struct arglist * globals;
   
       globals = arg_get_value(args, "globals");  
       upstream = (int)arg_get_value(globals, "global_socket");
@@ -1798,8 +1794,6 @@ ExtFunc unsigned int
 plug_get_host_open_port(struct arglist * desc)
 {
  struct kb_item ** kb = plug_get_kb(desc);
- char * t;
- int port = 0;
  struct kb_item * res, *k;
  int open21 = 0, open80 = 0;
 #define MAX_CANDIDATES 16
