@@ -248,7 +248,7 @@ struct arglist * store_load_plugin(char * dir, char * file,  struct arglist * pr
  
  struct arglist * ret;
  int i;
- struct stat st1, st2;
+ struct stat st1, st2, st3;
  struct arglist * al;
  
  bzero(pp, sizeof(pp));
@@ -278,6 +278,11 @@ struct arglist * store_load_plugin(char * dir, char * file,  struct arglist * pr
  snprintf(store_dir, sizeof(store_dir), "%s/.desc", dir);
  if(store_get_plugin_f(&p, pp, store_dir, file) < 0)
   return NULL;
+
+ if ( stat(p.path, &st3) == 0 )
+ {
+   if ( st1.st_ino != st3.st_ino ) return NULL;
+ }
   
  if(p.magic != MAGIC)
  	return NULL;
@@ -340,7 +345,7 @@ struct arglist * store_plugin(struct arglist * plugin, char * file)
  struct pprefs pp[MAX_PREFS+1];
  char  * str;
  char * dir;
- struct arglist * arglist, * ret,  *prefs;
+ struct arglist * arglist, *prefs;
  int e;
  int fd;
  int num_plugin_prefs = 0;
